/*
 * Copyright (C) 2019 Intel Corporation
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 */
package org.dripdronescanner.android.app;

import static android.content.Context.CLIPBOARD_SERVICE;

import android.app.AlertDialog;
import android.content.ClipData;
import android.content.ClipboardManager;
import android.os.Bundle;
import android.text.InputType;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.DialogFragment;
import androidx.lifecycle.ViewModelProvider;

import org.bouncycastle.util.encoders.DecoderException;
import org.bouncycastle.util.encoders.Hex;
import org.dripdronescanner.android.R;

import java.util.Locale;

public class DeviceDetailFragment extends DialogFragment {
    private TextView receiveTime;
    private TextView conMac;
    private TextView conRssi;
    private TextView conStarted;
    private TextView conLastUpdate;
    private TextView conMsgDelta;
    private TextView distance;

    private TextView infoLastUpdate;
    private TextView infoType;
    private TextView infoIdType;
    private TextView infoUasId;
    private TextView infoIDValidated;
    private Button copyIDBtn;

    private TextView posLastUpdate;
    private TextView status;
    private TextView heightType;
    private TextView direction;
    private TextView horiSpeed;
    private TextView vertSpeed;
    private TextView lat;
    private TextView lon;
    private TextView altitudePressure;
    private TextView altitudeGeodetic;
    private TextView height;
    private TextView horizontalAccuracy;
    private TextView verticalAccuracy;
    private TextView baroAccuracy;
    private TextView speedAccuracy;
    private TextView timestamp;
    private TextView timeAccuracy;

    private TextView authLastUpdate;
    private TextView authType;
    private TextView authTimestamp;
    private TextView authLength;
    private TextView authData;
    private Button manualAuthBtn;

    private TextView selfIdLastUpdate;
    private TextView selfIdType;
    private TextView selfIdDescription;

    private TextView systemLastUpdate;
    private TextView operatorLocationType;
    private TextView classificationType;
    private TextView systemLatitude;
    private TextView systemLongitude;
    private TextView systemAreaCount;
    private TextView systemAreaRadius;
    private TextView systemAreaCeiling;
    private TextView systemAreaFloor;
    private TextView category;
    private TextView classValue;

    private TextView operatorIdLastUpdate;
    private TextView operatorIdType;
    private TextView operatorId;

    static DeviceDetailFragment newInstance() {
        return new DeviceDetailFragment();
    }

    @Override
    public void onActivityCreated(@Nullable Bundle savedInstanceState) {
        if (getActivity() == null)
            return;

        super.onActivityCreated(savedInstanceState);
        DetailViewModel model = new ViewModelProvider(getActivity()).get(DetailViewModel.class);

        model.connection.observe(getViewLifecycleOwner(), connection -> {
            if (connection == null) return;
            String combo = connection.rssi + " dBm, " + connection.transportType;
            conRssi.setText(combo);
            conMac.setText(connection.macAddress);
            receiveTime.setText(connection.getTimestampAsString());
            conStarted.setText(String.format(Locale.US,"%s ago", DeviceList.elapsed(connection.firstSeen)));
            conLastUpdate.setText(String.format(Locale.US,"%s ago", DeviceList.elapsed(connection.lastSeen)));
            conMsgDelta.setText(connection.getMsgDeltaAsString());
        });

        model.identification.observe(getViewLifecycleOwner(), identification -> {
            if (identification == null) return;

            receiveTime.setText(identification.getTimestampAsString());
            infoLastUpdate.setText(identification.getADCounterAsString());
            infoType.setText(identification.getUaType().name());
            infoIdType.setText(identification.getIdType().name());
            infoUasId.setText(identification.getUasIdAsString());
            infoIDValidated.setText(identification.getIDValid());

        });

        model.location.observe(getViewLifecycleOwner(), locationData -> {
            if (locationData == null) return;

            receiveTime.setText(locationData.getTimestampAsString());
            posLastUpdate.setText(locationData.getADCounterAsString());
            status.setText(locationData.getStatus().name());
            direction.setText(locationData.getDirectionAsString());
            horiSpeed.setText(locationData.getSpeedHorizontalAsString());
            vertSpeed.setText(locationData.getSpeedVerticalAsString());
            lat.setText(locationData.getLatitudeAsString());
            lon.setText(locationData.getLongitudeAsString());
            altitudePressure.setText(locationData.getAltitudePressureAsString());
            altitudeGeodetic.setText(locationData.getAltitudeGeodeticAsString());
            heightType.setText(locationData.getHeightType().name());
            height.setText(locationData.getHeightAsString());
            horizontalAccuracy.setText(locationData.getHorizontalAccuracyAsString());
            verticalAccuracy.setText(locationData.getVerticalAccuracyAsString(locationData.getVerticalAccuracy()));
            baroAccuracy.setText(locationData.getVerticalAccuracyAsString(locationData.getBaroAccuracy()));
            speedAccuracy.setText(locationData.getSpeedAccuracyAsString());
            timestamp.setText(locationData.getLocationTimestampAsString());
            timeAccuracy.setText(locationData.getTimeAccuracyAsString());
            distance.setText(locationData.getDistanceAsString());
        });

        model.authentication.observe(getViewLifecycleOwner(), authenticationData -> {
            if (authenticationData == null) return;

            receiveTime.setText(authenticationData.getTimestampAsString());
            authLastUpdate.setText(authenticationData.getADCounterAsString());
            authType.setText(authenticationData.getAuthType().name());
            authLength.setText(authenticationData.getAuthLengthAsString());
            authTimestamp.setText(authenticationData.getAuthTimestampAsString());
            authData.setText(authenticationData.getAuthenticationDataAsString());
        });

        model.selfid.observe(getViewLifecycleOwner(), selfIdData -> {
            if (selfIdData == null) return;

            receiveTime.setText(selfIdData.getTimestampAsString());
            selfIdLastUpdate.setText(selfIdData.getADCounterAsString());
            selfIdType.setText(String.valueOf(selfIdData.getDescriptionType()));
            selfIdDescription.setText(new String(selfIdData.getOperationDescription()));
        });

        model.system.observe(getViewLifecycleOwner(), systemData -> {
            if (systemData == null) return;

            receiveTime.setText(systemData.getTimestampAsString());
            systemLastUpdate.setText(systemData.getADCounterAsString());
            operatorLocationType.setText(systemData.getOperatorLocationType().name());
            classificationType.setText(systemData.getclassificationType().name());
            systemLatitude.setText(systemData.getOperatorLatitudeAsString());
            systemLongitude.setText(systemData.getOperatorLongitudeAsString());
            systemAreaCount.setText(String.valueOf(systemData.getAreaCount()));
            systemAreaRadius.setText(systemData.getAreaRadiusAsString());
            systemAreaCeiling.setText(systemData.getAreaCeilingAsString());
            systemAreaFloor.setText(systemData.getAreaFloorAsString());
            category.setText(systemData.getCategory().name());
            classValue.setText(systemData.getClassValue().name());
        });

        model.operatorid.observe(getViewLifecycleOwner(), operatorIdData -> {
            if (operatorIdData == null) return;

            receiveTime.setText(operatorIdData.getTimestampAsString());
            operatorIdLastUpdate.setText(operatorIdData.getADCounterAsString());
            operatorIdType.setText(String.valueOf(operatorIdData.getOperatorIdType()));
            operatorId.setText(new String(operatorIdData.getOperatorId()));
        });
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {

        View view = inflater.inflate(R.layout.aircraft_details, container, false);
        receiveTime = view.findViewById(R.id.receiveTime);
        conMac = view.findViewById(R.id.conMac);
        conRssi = view.findViewById(R.id.conRssi);
        conStarted = view.findViewById(R.id.conStarted);
        conLastUpdate = view.findViewById(R.id.conLastUpdate);
        conMsgDelta = view.findViewById(R.id.conMsgDelta);
        distance = view.findViewById(R.id.distance);

        infoLastUpdate = view.findViewById(R.id.infoLastUpdate);
        infoType = view.findViewById(R.id.infoType);
        infoIdType = view.findViewById(R.id.infoIdType);
        infoUasId = view.findViewById(R.id.infoUasId);
        infoIDValidated = view.findViewById(R.id.infoIDValidated);
        copyIDBtn = view.findViewById(R.id.copyIDBtn);
        copyIDBtn.setOnClickListener(view1 -> {
            ClipboardManager clipboard = (ClipboardManager) view1.getContext().getSystemService(CLIPBOARD_SERVICE);
            ClipData clip = ClipData.newPlainText("ID", infoUasId.getText());
            clipboard.setPrimaryClip(clip);
        });

        posLastUpdate = view.findViewById(R.id.posLastUpdate);
        status = view.findViewById(R.id.status);
        direction = view.findViewById(R.id.direction);
        horiSpeed = view.findViewById(R.id.horiSpeed);
        vertSpeed = view.findViewById(R.id.vertSpeed);
        lat = view.findViewById(R.id.lat);
        lon = view.findViewById(R.id.lon);
        altitudePressure = view.findViewById(R.id.altitudePressure);
        altitudeGeodetic = view.findViewById(R.id.altitudeGeodetic);
        heightType = view.findViewById(R.id.heightType);
        height = view.findViewById(R.id.height);
        horizontalAccuracy = view.findViewById(R.id.horizontalAccuracy);
        verticalAccuracy = view.findViewById(R.id.verticalAccuracy);
        baroAccuracy = view.findViewById(R.id.baroAccuracy);
        speedAccuracy = view.findViewById(R.id.speedAccuracy);
        timestamp = view.findViewById(R.id.timestamp);
        timeAccuracy = view.findViewById(R.id.timeAccuracy);

        authLastUpdate = view.findViewById(R.id.authLastUpdate);
        authType = view.findViewById(R.id.authType);
        authLength = view.findViewById(R.id.authLength);
        authTimestamp = view.findViewById(R.id.authTimestamp);
        authData = view.findViewById(R.id.authData);
        manualAuthBtn = view.findViewById(R.id.manAuthBtn);
        manualAuthBtn.setOnClickListener(view2 -> {
            AlertDialog.Builder builder = new AlertDialog.Builder(view2.getContext());
            builder.setTitle("Enter public key");

            // Set up the input
            final EditText textInput = new EditText(view2.getContext());
            // Specify the type of input expected; this, for example, sets the input as a password, and will mask the text
            textInput.setInputType(InputType.TYPE_CLASS_TEXT);
            builder.setView(textInput);

            // Set up the buttons
            builder.setPositiveButton("OK", (dialog, which) -> {
                String pubKey = textInput.getText().toString();
                byte[] decoded;
                try {
                    decoded = Hex.decode(pubKey);
                } catch (DecoderException e) {
                    e.printStackTrace();
                    Toast.makeText(view.getContext(),
                            "Bad hex string, could not decode.",
                            Toast.LENGTH_LONG).show();
                    return;
                }

                DetailViewModel model = new ViewModelProvider(getActivity()).get(DetailViewModel.class);
                model.getSelected().getValue().setPubKey(decoded);
                boolean isValid = model.authentication.getValue().validate(
                        model.identification.getValue().getUasId(),
                        model.getSelected().getValue().getPubkey()
                );
                if(!isValid){
                    model.authentication.getValue().setServerIssues(decoded.length == 0);
                    Toast.makeText(view.getContext(),
                            "Authentication failed, Either you entered " +
                                    "the public key incorrectly or the identity is Invalid",
                            Toast.LENGTH_LONG).show();
                }else{
                    model.authentication.getValue().setServerIssues(false);
                }
                System.out.println("validating id");
                 model.identification.getValue().validateId(decoded);

            });
            builder.setNegativeButton("Cancel", (dialog, which) -> dialog.cancel());

            builder.show();
        });

        selfIdLastUpdate = view.findViewById(R.id.selfIdLastUpdate);
        selfIdType = view.findViewById(R.id.selfIdType);
        selfIdDescription = view.findViewById(R.id.selfIdDescription);

        systemLastUpdate = view.findViewById(R.id.systemLastUpdate);
        operatorLocationType = view.findViewById(R.id.operatorLocationType);
        classificationType = view.findViewById(R.id.classificationType);
        systemLatitude = view.findViewById(R.id.systemLatitude);
        systemLongitude = view.findViewById(R.id.systemLongitude);
        systemAreaCount = view.findViewById(R.id.systemAreaCount);
        systemAreaRadius = view.findViewById(R.id.systemAreaRadius);
        systemAreaCeiling = view.findViewById(R.id.systemAreaCeiling);
        systemAreaFloor = view.findViewById(R.id.systemAreaFloor);
        category = view.findViewById(R.id.category);
        classValue = view.findViewById(R.id.classValue);

        operatorIdLastUpdate = view.findViewById(R.id.operatorIdLastUpdate);
        operatorIdType = view.findViewById(R.id.operatorIdType);
        operatorId = view.findViewById(R.id.operatorId);
        return view;
    }
}
